@@ -15,7 +15,7 @@ def align_timestamps_stock_dataframes(stocks_data_dfs, timestamps_as_index=False
     for i, stock_df in enumerate(stocks_data_dfs):
         stock_df = pd.merge(stock_df, timedf, how='right', left_on='TimeStamp', right_on='AllTime').ffill()
         stock_df = stock_df.loc[~np.isnan(stock_df['TimeStamp']), stock_df.columns[:-1]]
-        stock_df['TimeStamp'] = timedf.loc[(len(timedf)-len(stock_df)):, 'AllTime'].ravel()
+        stock_df.loc[:, 'TimeStamp'] = timedf.loc[(len(timedf)-len(stock_df)):, 'AllTime'].ravel()
         stock_df = stock_df.reset_index()
         stock_df = stock_df.drop(['index'], axis=1)
         if timestamps_as_index:
